# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/proposal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from fxsdk.x.fx.dex.v1 import funding_pb2 as fx_dot_dex_dot_v1_dot_funding__pb2
from fxsdk.x.fx.dex.v1 import margin_pb2 as fx_dot_dex_dot_v1_dot_margin__pb2
from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x66x/dex/v1/proposal.proto\x12\tfx.dex.v1\x1a\x14gogoproto/gogo.proto\x1a\x17\x66x/dex/v1/funding.proto\x1a\x16\x66x/dex/v1/margin.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"z\n\x18ResetFundingTimeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12,\n\x0c\x66unding_time\x18\x03 \x01(\x0b\x32\x16.fx.dex.v1.FundingTime:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"z\n\x1aResetFundingParamsProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12*\n\x0e\x66unding_params\x18\x03 \x01(\x0b\x32\x12.fx.dex.v1.Funding:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x81\x01\n\x15ResetMMATableProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x36\n\x12margin_rate_tables\x18\x03 \x03(\x0b\x32\x1a.fx.dex.v1.MarginRateTable:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"e\n\x12\x43reatePairProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1d\n\x04pair\x18\x03 \x01(\x0b\x32\x0f.fx.dex.v1.Pair:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xa0\x01\n\x04Pair\x12\x12\n\nbase_asset\x18\x01 \x01(\t\x12\x13\n\x0bquote_asset\x18\x02 \x01(\t\x12\x15\n\rmarket_status\x18\x03 \x01(\x03\x12\x15\n\rprice_decimal\x18\x04 \x01(\x03\x12\x18\n\x10position_decimal\x18\x05 \x01(\x03\x12\x12\n\ninit_price\x18\x06 \x01(\t\x12\x13\n\x0bmarket_type\x18\x07 \x01(\t\"\x8c\x01\n\x1fResetPremiumIndexConfigProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x37\n\x12premium_index_conf\x18\x03 \x01(\x0b\x32\x1b.fx.dex.v1.PremiumIndexConf:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"k\n\x12ShareSplitProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nmultiplier\x18\x03 \x01(\t\x12\x0f\n\x07pair_id\x18\x04 \x01(\t:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xbb\x01\n\x17TradingFeeSpendProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\trecipient\x18\x03 \x01(\t\x12[\n\x06\x61mount\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xed\x01\n\"TradingFeeSpendProposalWithDeposit\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"title\"\x12+\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"description\"\x12\'\n\trecipient\x18\x03 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"recipient\"\x12!\n\x06\x61mount\x18\x04 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"amount\"\x12#\n\x07\x64\x65posit\x18\x05 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"deposit\":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01\"m\n\x12UnlistPairProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07pair_id\x18\x03 \x01(\t\x12\x14\n\x0c\x66\x65\x65_receiver\x18\x04 \x01(\t:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"o\n\x14SendToFxcoreProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x66\x65\x65_receiver\x18\x03 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x04 \x01(\t:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\x42-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.proposal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _RESETFUNDINGTIMEPROPOSAL._options = None
  _RESETFUNDINGTIMEPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _RESETFUNDINGPARAMSPROPOSAL._options = None
  _RESETFUNDINGPARAMSPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _RESETMMATABLEPROPOSAL._options = None
  _RESETMMATABLEPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _CREATEPAIRPROPOSAL._options = None
  _CREATEPAIRPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _RESETPREMIUMINDEXCONFIGPROPOSAL._options = None
  _RESETPREMIUMINDEXCONFIGPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _SHARESPLITPROPOSAL._options = None
  _SHARESPLITPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _TRADINGFEESPENDPROPOSAL.fields_by_name['amount']._options = None
  _TRADINGFEESPENDPROPOSAL.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _TRADINGFEESPENDPROPOSAL._options = None
  _TRADINGFEESPENDPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['title']._options = None
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['title']._serialized_options = b'\362\336\037\014yaml:\"title\"'
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['description']._options = None
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['description']._serialized_options = b'\362\336\037\022yaml:\"description\"'
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['recipient']._options = None
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['recipient']._serialized_options = b'\362\336\037\020yaml:\"recipient\"'
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['amount']._options = None
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['amount']._serialized_options = b'\362\336\037\ryaml:\"amount\"'
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['deposit']._options = None
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT.fields_by_name['deposit']._serialized_options = b'\362\336\037\016yaml:\"deposit\"'
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT._options = None
  _TRADINGFEESPENDPROPOSALWITHDEPOSIT._serialized_options = b'\210\240\037\000\230\240\037\001'
  _UNLISTPAIRPROPOSAL._options = None
  _UNLISTPAIRPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _SENDTOFXCOREPROPOSAL._options = None
  _SENDTOFXCOREPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _globals['_RESETFUNDINGTIMEPROPOSAL']._serialized_start=142
  _globals['_RESETFUNDINGTIMEPROPOSAL']._serialized_end=264
  _globals['_RESETFUNDINGPARAMSPROPOSAL']._serialized_start=266
  _globals['_RESETFUNDINGPARAMSPROPOSAL']._serialized_end=388
  _globals['_RESETMMATABLEPROPOSAL']._serialized_start=391
  _globals['_RESETMMATABLEPROPOSAL']._serialized_end=520
  _globals['_CREATEPAIRPROPOSAL']._serialized_start=522
  _globals['_CREATEPAIRPROPOSAL']._serialized_end=623
  _globals['_PAIR']._serialized_start=626
  _globals['_PAIR']._serialized_end=786
  _globals['_RESETPREMIUMINDEXCONFIGPROPOSAL']._serialized_start=789
  _globals['_RESETPREMIUMINDEXCONFIGPROPOSAL']._serialized_end=929
  _globals['_SHARESPLITPROPOSAL']._serialized_start=931
  _globals['_SHARESPLITPROPOSAL']._serialized_end=1038
  _globals['_TRADINGFEESPENDPROPOSAL']._serialized_start=1041
  _globals['_TRADINGFEESPENDPROPOSAL']._serialized_end=1228
  _globals['_TRADINGFEESPENDPROPOSALWITHDEPOSIT']._serialized_start=1231
  _globals['_TRADINGFEESPENDPROPOSALWITHDEPOSIT']._serialized_end=1468
  _globals['_UNLISTPAIRPROPOSAL']._serialized_start=1470
  _globals['_UNLISTPAIRPROPOSAL']._serialized_end=1579
  _globals['_SENDTOFXCOREPROPOSAL']._serialized_start=1581
  _globals['_SENDTOFXCOREPROPOSAL']._serialized_end=1692
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from fxsdk.x.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from fxsdk.x.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/bank/v1beta1/tx.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\xdf\x01\n\x07MsgSend\x12.\n\x0c\x66rom_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12,\n\nto_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12[\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x19\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x0c\x66rom_address\"\x11\n\x0fMsgSendResponse\"\x85\x01\n\x0cMsgMultiSend\x12\x30\n\x06inputs\x18\x01 \x03(\x0b\x32\x1a.cosmos.bank.v1beta1.InputB\x04\xc8\xde\x1f\x00\x12\x32\n\x07outputs\x18\x02 \x03(\x0b\x32\x1b.cosmos.bank.v1beta1.OutputB\x04\xc8\xde\x1f\x00:\x0f\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06inputs\"\x16\n\x14MsgMultiSendResponse2\xac\x01\n\x03Msg\x12J\n\x04Send\x12\x1c.cosmos.bank.v1beta1.MsgSend\x1a$.cosmos.bank.v1beta1.MsgSendResponse\x12Y\n\tMultiSend\x12!.cosmos.bank.v1beta1.MsgMultiSend\x1a).cosmos.bank.v1beta1.MsgMultiSendResponseB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _MSGSEND.fields_by_name['from_address']._options = None
  _MSGSEND.fields_by_name['from_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSEND.fields_by_name['to_address']._options = None
  _MSGSEND.fields_by_name['to_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSEND.fields_by_name['amount']._options = None
  _MSGSEND.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGSEND._options = None
  _MSGSEND._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\014from_address'
  _MSGMULTISEND.fields_by_name['inputs']._options = None
  _MSGMULTISEND.fields_by_name['inputs']._serialized_options = b'\310\336\037\000'
  _MSGMULTISEND.fields_by_name['outputs']._options = None
  _MSGMULTISEND.fields_by_name['outputs']._serialized_options = b'\310\336\037\000'
  _MSGMULTISEND._options = None
  _MSGMULTISEND._serialized_options = b'\350\240\037\000\202\347\260*\006inputs'
  _globals['_MSGSEND']._serialized_start=192
  _globals['_MSGSEND']._serialized_end=415
  _globals['_MSGSENDRESPONSE']._serialized_start=417
  _globals['_MSGSENDRESPONSE']._serialized_end=434
  _globals['_MSGMULTISEND']._serialized_start=437
  _globals['_MSGMULTISEND']._serialized_end=570
  _globals['_MSGMULTISENDRESPONSE']._serialized_start=572
  _globals['_MSGMULTISENDRESPONSE']._serialized_end=594
  _globals['_MSG']._serialized_start=597
  _globals['_MSG']._serialized_end=769
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.fx.crosschain.v1 import query_pb2 as fx_dot_crosschain_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/Params',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.CurrentOracleSet = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/CurrentOracleSet',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryCurrentOracleSetRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryCurrentOracleSetResponse.FromString,
                )
        self.OracleSetRequest = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/OracleSetRequest',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetRequestRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetRequestResponse.FromString,
                )
        self.OracleSetConfirm = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/OracleSetConfirm',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmResponse.FromString,
                )
        self.OracleSetConfirmsByNonce = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/OracleSetConfirmsByNonce',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmsByNonceRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmsByNonceResponse.FromString,
                )
        self.LastOracleSetRequests = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/LastOracleSetRequests',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastOracleSetRequestsRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastOracleSetRequestsResponse.FromString,
                )
        self.LastPendingOracleSetRequestByAddr = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/LastPendingOracleSetRequestByAddr',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingOracleSetRequestByAddrRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingOracleSetRequestByAddrResponse.FromString,
                )
        self.LastPendingBatchRequestByAddr = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/LastPendingBatchRequestByAddr',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrResponse.FromString,
                )
        self.LastEventNonceByAddr = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/LastEventNonceByAddr',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventNonceByAddrRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventNonceByAddrResponse.FromString,
                )
        self.LastEventBlockHeightByAddr = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/LastEventBlockHeightByAddr',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventBlockHeightByAddrRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventBlockHeightByAddrResponse.FromString,
                )
        self.BatchFees = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/BatchFees',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchFeeRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchFeeResponse.FromString,
                )
        self.LastObservedBlockHeight = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/LastObservedBlockHeight',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastObservedBlockHeightRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastObservedBlockHeightResponse.FromString,
                )
        self.OutgoingTxBatches = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/OutgoingTxBatches',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesResponse.FromString,
                )
        self.BatchRequestByNonce = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/BatchRequestByNonce',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchRequestByNonceRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchRequestByNonceResponse.FromString,
                )
        self.BatchConfirm = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/BatchConfirm',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmResponse.FromString,
                )
        self.BatchConfirms = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/BatchConfirms',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmsRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmsResponse.FromString,
                )
        self.TokenToDenom = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/TokenToDenom',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryTokenToDenomRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryTokenToDenomResponse.FromString,
                )
        self.DenomToToken = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/DenomToToken',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryDenomToTokenRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryDenomToTokenResponse.FromString,
                )
        self.GetOracleByAddr = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/GetOracleByAddr',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByAddrRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.FromString,
                )
        self.GetOracleByExternalAddr = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/GetOracleByExternalAddr',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByExternalAddrRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.FromString,
                )
        self.GetOracleByBridgerAddr = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/GetOracleByBridgerAddr',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByBridgerAddrRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.FromString,
                )
        self.GetPendingSendToExternal = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/GetPendingSendToExternal',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryPendingSendToExternalRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryPendingSendToExternalResponse.FromString,
                )
        self.Oracles = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/Oracles',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOraclesRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOraclesResponse.FromString,
                )
        self.ProjectedBatchTimeoutHeight = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/ProjectedBatchTimeoutHeight',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryProjectedBatchTimeoutHeightRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryProjectedBatchTimeoutHeightResponse.FromString,
                )
        self.BridgeTokens = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/BridgeTokens',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeTokensRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeTokensResponse.FromString,
                )
        self.BridgeCoinByDenom = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/BridgeCoinByDenom',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeCoinByDenomRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeCoinByDenomResponse.FromString,
                )
        self.BridgeChainList = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Query/BridgeChainList',
                request_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeChainListRequest.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeChainListResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service
    """

    def Params(self, request, context):
        """Deployments queries deployments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CurrentOracleSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleSetRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleSetConfirm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleSetConfirmsByNonce(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastOracleSetRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastPendingOracleSetRequestByAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastPendingBatchRequestByAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastEventNonceByAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastEventBlockHeightByAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchFees(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastObservedBlockHeight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OutgoingTxBatches(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchRequestByNonce(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchConfirm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchConfirms(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TokenToDenom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomToToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOracleByAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOracleByExternalAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOracleByBridgerAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingSendToExternal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Oracles(self, request, context):
        """Validators queries all oracle that match the given status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProjectedBatchTimeoutHeight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BridgeTokens(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BridgeCoinByDenom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BridgeChainList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'CurrentOracleSet': grpc.unary_unary_rpc_method_handler(
                    servicer.CurrentOracleSet,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryCurrentOracleSetRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryCurrentOracleSetResponse.SerializeToString,
            ),
            'OracleSetRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleSetRequest,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetRequestRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetRequestResponse.SerializeToString,
            ),
            'OracleSetConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleSetConfirm,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmResponse.SerializeToString,
            ),
            'OracleSetConfirmsByNonce': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleSetConfirmsByNonce,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmsByNonceRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmsByNonceResponse.SerializeToString,
            ),
            'LastOracleSetRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.LastOracleSetRequests,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastOracleSetRequestsRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastOracleSetRequestsResponse.SerializeToString,
            ),
            'LastPendingOracleSetRequestByAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.LastPendingOracleSetRequestByAddr,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingOracleSetRequestByAddrRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingOracleSetRequestByAddrResponse.SerializeToString,
            ),
            'LastPendingBatchRequestByAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.LastPendingBatchRequestByAddr,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrResponse.SerializeToString,
            ),
            'LastEventNonceByAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.LastEventNonceByAddr,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventNonceByAddrRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventNonceByAddrResponse.SerializeToString,
            ),
            'LastEventBlockHeightByAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.LastEventBlockHeightByAddr,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventBlockHeightByAddrRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventBlockHeightByAddrResponse.SerializeToString,
            ),
            'BatchFees': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchFees,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchFeeRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchFeeResponse.SerializeToString,
            ),
            'LastObservedBlockHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.LastObservedBlockHeight,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastObservedBlockHeightRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastObservedBlockHeightResponse.SerializeToString,
            ),
            'OutgoingTxBatches': grpc.unary_unary_rpc_method_handler(
                    servicer.OutgoingTxBatches,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesResponse.SerializeToString,
            ),
            'BatchRequestByNonce': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchRequestByNonce,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchRequestByNonceRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchRequestByNonceResponse.SerializeToString,
            ),
            'BatchConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchConfirm,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmResponse.SerializeToString,
            ),
            'BatchConfirms': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchConfirms,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmsRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmsResponse.SerializeToString,
            ),
            'TokenToDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.TokenToDenom,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryTokenToDenomRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryTokenToDenomResponse.SerializeToString,
            ),
            'DenomToToken': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomToToken,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryDenomToTokenRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryDenomToTokenResponse.SerializeToString,
            ),
            'GetOracleByAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOracleByAddr,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByAddrRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.SerializeToString,
            ),
            'GetOracleByExternalAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOracleByExternalAddr,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByExternalAddrRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.SerializeToString,
            ),
            'GetOracleByBridgerAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOracleByBridgerAddr,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByBridgerAddrRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.SerializeToString,
            ),
            'GetPendingSendToExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingSendToExternal,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryPendingSendToExternalRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryPendingSendToExternalResponse.SerializeToString,
            ),
            'Oracles': grpc.unary_unary_rpc_method_handler(
                    servicer.Oracles,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOraclesRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOraclesResponse.SerializeToString,
            ),
            'ProjectedBatchTimeoutHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.ProjectedBatchTimeoutHeight,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryProjectedBatchTimeoutHeightRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryProjectedBatchTimeoutHeightResponse.SerializeToString,
            ),
            'BridgeTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.BridgeTokens,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeTokensRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeTokensResponse.SerializeToString,
            ),
            'BridgeCoinByDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.BridgeCoinByDenom,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeCoinByDenomRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeCoinByDenomResponse.SerializeToString,
            ),
            'BridgeChainList': grpc.unary_unary_rpc_method_handler(
                    servicer.BridgeChainList,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeChainListRequest.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeChainListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fx.gravity.crosschain.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/Params',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CurrentOracleSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/CurrentOracleSet',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryCurrentOracleSetRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryCurrentOracleSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OracleSetRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/OracleSetRequest',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetRequestRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OracleSetConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/OracleSetConfirm',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OracleSetConfirmsByNonce(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/OracleSetConfirmsByNonce',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmsByNonceRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleSetConfirmsByNonceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastOracleSetRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/LastOracleSetRequests',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastOracleSetRequestsRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastOracleSetRequestsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastPendingOracleSetRequestByAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/LastPendingOracleSetRequestByAddr',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingOracleSetRequestByAddrRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingOracleSetRequestByAddrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastPendingBatchRequestByAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/LastPendingBatchRequestByAddr',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastEventNonceByAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/LastEventNonceByAddr',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventNonceByAddrRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventNonceByAddrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastEventBlockHeightByAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/LastEventBlockHeightByAddr',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventBlockHeightByAddrRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastEventBlockHeightByAddrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchFees(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/BatchFees',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchFeeRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchFeeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastObservedBlockHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/LastObservedBlockHeight',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastObservedBlockHeightRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryLastObservedBlockHeightResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OutgoingTxBatches(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/OutgoingTxBatches',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchRequestByNonce(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/BatchRequestByNonce',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchRequestByNonceRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchRequestByNonceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/BatchConfirm',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchConfirms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/BatchConfirms',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmsRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBatchConfirmsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TokenToDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/TokenToDenom',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryTokenToDenomRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryTokenToDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomToToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/DenomToToken',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryDenomToTokenRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryDenomToTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOracleByAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/GetOracleByAddr',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByAddrRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOracleByExternalAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/GetOracleByExternalAddr',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByExternalAddrRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOracleByBridgerAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/GetOracleByBridgerAddr',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleByBridgerAddrRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOracleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPendingSendToExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/GetPendingSendToExternal',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryPendingSendToExternalRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryPendingSendToExternalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Oracles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/Oracles',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOraclesRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryOraclesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProjectedBatchTimeoutHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/ProjectedBatchTimeoutHeight',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryProjectedBatchTimeoutHeightRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryProjectedBatchTimeoutHeightResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BridgeTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/BridgeTokens',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeTokensRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BridgeCoinByDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/BridgeCoinByDenom',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeCoinByDenomRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeCoinByDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BridgeChainList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Query/BridgeChainList',
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeChainListRequest.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_query__pb2.QueryBridgeChainListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/migrate/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.fx.migrate.v1 import migrate_pb2 as fx_dot_migrate_dot_v1_dot_migrate__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66x/migrate/v1/genesis.proto\x12\rfx.migrate.v1\x1a\x1b\x66x/migrate/v1/migrate.proto\x1a\x14gogoproto/gogo.proto\"K\n\x0cGenesisState\x12;\n\x0fmigrate_records\x18\x01 \x03(\x0b\x32\x1c.fx.migrate.v1.MigrateRecordB\x04\xc8\xde\x1f\x00\x42.Z,github.com/functionx/fx-core/x/migrate/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.migrate.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/functionx/fx-core/x/migrate/types'
  _GENESISSTATE.fields_by_name['migrate_records']._options = None
  _GENESISSTATE.fields_by_name['migrate_records']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=97
  _globals['_GENESISSTATE']._serialized_end=172
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethermint/types/v1/indexer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ethermint/types/v1/indexer.proto\x12\x12\x65thermint.types.v1\x1a\x14gogoproto/gogo.proto\"\x9a\x01\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x10\n\x08tx_index\x18\x02 \x01(\r\x12\x11\n\tmsg_index\x18\x03 \x01(\r\x12\x14\n\x0c\x65th_tx_index\x18\x04 \x01(\x05\x12\x0e\n\x06\x66\x61iled\x18\x05 \x01(\x08\x12\x10\n\x08gas_used\x18\x06 \x01(\x04\x12\x1b\n\x13\x63umulative_gas_used\x18\x07 \x01(\x04:\x04\x88\xa0\x1f\x00\x42\"Z github.com/evmos/ethermint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ethermint.types.v1.indexer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z github.com/evmos/ethermint/types'
  _TXRESULT._options = None
  _TXRESULT._serialized_options = b'\210\240\037\000'
  _globals['_TXRESULT']._serialized_start=79
  _globals['_TXRESULT']._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/migrate/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.fx.migrate.v1 import migrate_pb2 as fx_dot_migrate_dot_v1_dot_migrate__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x66x/migrate/v1/query.proto\x12\rfx.migrate.v1\x1a\x1b\x66x/migrate/v1/migrate.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\",\n\x19QueryMigrateRecordRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"f\n\x1aQueryMigrateRecordResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\x39\n\rmigrateRecord\x18\x02 \x01(\x0b\x32\x1c.fx.migrate.v1.MigrateRecordB\x04\xc8\xde\x1f\x00\";\n\x1fQueryMigrateCheckAccountRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\"\"\n QueryMigrateCheckAccountResponse2\xb6\x02\n\x05Query\x12\x8d\x01\n\rMigrateRecord\x12(.fx.migrate.v1.QueryMigrateRecordRequest\x1a).fx.migrate.v1.QueryMigrateRecordResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/fx/migrate/v1/record/{address}\x12\x9c\x01\n\x13MigrateCheckAccount\x12..fx.migrate.v1.QueryMigrateCheckAccountRequest\x1a/.fx.migrate.v1.QueryMigrateCheckAccountResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/fx/migrate/v1/check/accountB.Z,github.com/functionx/fx-core/x/migrate/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.migrate.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/functionx/fx-core/x/migrate/types'
  _QUERYMIGRATERECORDRESPONSE.fields_by_name['migrateRecord']._options = None
  _QUERYMIGRATERECORDRESPONSE.fields_by_name['migrateRecord']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['MigrateRecord']._options = None
  _QUERY.methods_by_name['MigrateRecord']._serialized_options = b'\202\323\344\223\002!\022\037/fx/migrate/v1/record/{address}'
  _QUERY.methods_by_name['MigrateCheckAccount']._options = None
  _QUERY.methods_by_name['MigrateCheckAccount']._serialized_options = b'\202\323\344\223\002\036\022\034/fx/migrate/v1/check/account'
  _globals['_QUERYMIGRATERECORDREQUEST']._serialized_start=125
  _globals['_QUERYMIGRATERECORDREQUEST']._serialized_end=169
  _globals['_QUERYMIGRATERECORDRESPONSE']._serialized_start=171
  _globals['_QUERYMIGRATERECORDRESPONSE']._serialized_end=273
  _globals['_QUERYMIGRATECHECKACCOUNTREQUEST']._serialized_start=275
  _globals['_QUERYMIGRATECHECKACCOUNTREQUEST']._serialized_end=334
  _globals['_QUERYMIGRATECHECKACCOUNTRESPONSE']._serialized_start=336
  _globals['_QUERYMIGRATECHECKACCOUNTRESPONSE']._serialized_end=370
  _globals['_QUERY']._serialized_start=373
  _globals['_QUERY']._serialized_end=683
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethermint/types/v1/web3.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65thermint/types/v1/web3.proto\x12\x12\x65thermint.types.v1\x1a\x14gogoproto/gogo.proto\"\xcc\x01\n\x16\x45xtensionOptionsWeb3Tx\x12O\n\x13typed_data_chain_id\x18\x01 \x01(\x04\x42\x32\xe2\xde\x1f\x10TypedDataChainID\xea\xde\x1f\x1atypedDataChainID,omitempty\x12)\n\tfee_payer\x18\x02 \x01(\tB\x16\xea\xde\x1f\x12\x66\x65\x65Payer,omitempty\x12\x30\n\rfee_payer_sig\x18\x03 \x01(\x0c\x42\x19\xea\xde\x1f\x15\x66\x65\x65PayerSig,omitempty:\x04\x88\xa0\x1f\x00\x42\"Z github.com/evmos/ethermint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ethermint.types.v1.web3_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z github.com/evmos/ethermint/types'
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['typed_data_chain_id']._options = None
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['typed_data_chain_id']._serialized_options = b'\342\336\037\020TypedDataChainID\352\336\037\032typedDataChainID,omitempty'
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['fee_payer']._options = None
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['fee_payer']._serialized_options = b'\352\336\037\022feePayer,omitempty'
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['fee_payer_sig']._options = None
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['fee_payer_sig']._serialized_options = b'\352\336\037\025feePayerSig,omitempty'
  _EXTENSIONOPTIONSWEB3TX._options = None
  _EXTENSIONOPTIONSWEB3TX._serialized_options = b'\210\240\037\000'
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_start=76
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_end=280
# @@protoc_insertion_point(module_scope)



import re

from fxsdk.x.cosmos.base.v1beta1.coin_pb2 import Coin


def parse_coins(value: str) -> [Coin]:
    """Parse the coins.

    :param value: coins
    :raises RuntimeError: If unable to parse the value
    :return: coins
    """
    coins = []
    parts = value.split(',')
    for part in parts:
        part = part.strip()
        if part == "":
            continue
        coins.append(parse_coin(part))

    return coins


def parse_coin(value: str) -> Coin:
    match = re.match(r"(\d+.\d+)(\w+)", value)
    if match is None:
        raise RuntimeError(f"Unable to parse value {value}")

    # extract out the groups
    amount, denom = match.groups()
    return Coin(amount=amount, denom=denom)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/legacy/gravity/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.fx.legacy.gravity.v1 import types_pb2 as fx_dot_legacy_dot_gravity_dot_v1_dot_types__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x66x/legacy/gravity/v1/tx.proto\x12\rfx.gravity.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a fx/legacy/gravity/v1/types.proto\x1a\x14gogoproto/gogo.proto\"_\n\x10MsgValsetConfirm\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x14\n\x0corchestrator\x18\x02 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\t\"\x1a\n\x18MsgValsetConfirmResponse\"\x96\x01\n\x0cMsgSendToEth\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x65th_dest\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x33\n\nbridge_fee\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x16\n\x14MsgSendToEthResponse\"\xcb\x01\n\x0fMsgRequestBatch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x43\n\x0bminimum_fee\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x12\n\nfeeReceive\x18\x04 \x01(\t\x12@\n\x08\x62\x61se_fee\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"\x19\n\x17MsgRequestBatchResponse\"u\n\x0fMsgConfirmBatch\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x02 \x01(\t\x12\x12\n\neth_signer\x18\x03 \x01(\t\x12\x14\n\x0corchestrator\x18\x04 \x01(\t\x12\x11\n\tsignature\x18\x05 \x01(\t\"\x19\n\x17MsgConfirmBatchResponse\"\xe7\x01\n\x0fMsgDepositClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x03 \x01(\t\x12>\n\x06\x61mount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x12\n\neth_sender\x18\x05 \x01(\t\x12\x13\n\x0b\x66x_receiver\x18\x06 \x01(\t\x12\x12\n\ntarget_ibc\x18\x07 \x01(\t\x12\x14\n\x0corchestrator\x18\x08 \x01(\t\"\x19\n\x17MsgDepositClaimResponse\"\x80\x01\n\x10MsgWithdrawClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x13\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\x14\n\x0corchestrator\x18\x05 \x01(\t\"\x1a\n\x18MsgWithdrawClaimResponse\"<\n\x12MsgCancelSendToEth\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\"\x1c\n\x1aMsgCancelSendToEthResponse\"\x9f\x01\n\x15MsgValsetUpdatedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x14\n\x0cvalset_nonce\x18\x03 \x01(\x04\x12/\n\x07members\x18\x04 \x03(\x0b\x32\x1e.fx.gravity.v1.BridgeValidator\x12\x14\n\x0corchestrator\x18\x06 \x01(\t\"\x1f\n\x1dMsgValsetUpdatedClaimResponse\"Y\n\x19MsgSetOrchestratorAddress\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x14\n\x0corchestrator\x18\x02 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\"#\n!MsgSetOrchestratorAddressResponse\"\xa4\x01\n\x19MsgFxOriginatedTokenClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06symbol\x18\x05 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x06 \x01(\x04\x12\x14\n\x0corchestrator\x18\x07 \x01(\t\"#\n!MsgFxOriginatedTokenClaimResponse2\xdc\x05\n\x03Msg\x12Y\n\rValsetConfirm\x12\x1f.fx.gravity.v1.MsgValsetConfirm\x1a\'.fx.gravity.v1.MsgValsetConfirmResponse\x12M\n\tSendToEth\x12\x1b.fx.gravity.v1.MsgSendToEth\x1a#.fx.gravity.v1.MsgSendToEthResponse\x12V\n\x0cRequestBatch\x12\x1e.fx.gravity.v1.MsgRequestBatch\x1a&.fx.gravity.v1.MsgRequestBatchResponse\x12V\n\x0c\x43onfirmBatch\x12\x1e.fx.gravity.v1.MsgConfirmBatch\x1a&.fx.gravity.v1.MsgConfirmBatchResponse\x12V\n\x0c\x44\x65positClaim\x12\x1e.fx.gravity.v1.MsgDepositClaim\x1a&.fx.gravity.v1.MsgDepositClaimResponse\x12Y\n\rWithdrawClaim\x12\x1f.fx.gravity.v1.MsgWithdrawClaim\x1a\'.fx.gravity.v1.MsgWithdrawClaimResponse\x12_\n\x0f\x43\x61ncelSendToEth\x12!.fx.gravity.v1.MsgCancelSendToEth\x1a).fx.gravity.v1.MsgCancelSendToEthResponse\x12g\n\x11ValsetUpdateClaim\x12$.fx.gravity.v1.MsgValsetUpdatedClaim\x1a,.fx.gravity.v1.MsgValsetUpdatedClaimResponseB.Z,github.com/functionx/fx-core/x/gravity/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.legacy.gravity.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/functionx/fx-core/x/gravity/types'
  _MSGSENDTOETH.fields_by_name['amount']._options = None
  _MSGSENDTOETH.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGSENDTOETH.fields_by_name['bridge_fee']._options = None
  _MSGSENDTOETH.fields_by_name['bridge_fee']._serialized_options = b'\310\336\037\000'
  _MSGREQUESTBATCH.fields_by_name['minimum_fee']._options = None
  _MSGREQUESTBATCH.fields_by_name['minimum_fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MSGREQUESTBATCH.fields_by_name['base_fee']._options = None
  _MSGREQUESTBATCH.fields_by_name['base_fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MSGDEPOSITCLAIM.fields_by_name['amount']._options = None
  _MSGDEPOSITCLAIM.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _globals['_MSGVALSETCONFIRM']._serialized_start=136
  _globals['_MSGVALSETCONFIRM']._serialized_end=231
  _globals['_MSGVALSETCONFIRMRESPONSE']._serialized_start=233
  _globals['_MSGVALSETCONFIRMRESPONSE']._serialized_end=259
  _globals['_MSGSENDTOETH']._serialized_start=262
  _globals['_MSGSENDTOETH']._serialized_end=412
  _globals['_MSGSENDTOETHRESPONSE']._serialized_start=414
  _globals['_MSGSENDTOETHRESPONSE']._serialized_end=436
  _globals['_MSGREQUESTBATCH']._serialized_start=439
  _globals['_MSGREQUESTBATCH']._serialized_end=642
  _globals['_MSGREQUESTBATCHRESPONSE']._serialized_start=644
  _globals['_MSGREQUESTBATCHRESPONSE']._serialized_end=669
  _globals['_MSGCONFIRMBATCH']._serialized_start=671
  _globals['_MSGCONFIRMBATCH']._serialized_end=788
  _globals['_MSGCONFIRMBATCHRESPONSE']._serialized_start=790
  _globals['_MSGCONFIRMBATCHRESPONSE']._serialized_end=815
  _globals['_MSGDEPOSITCLAIM']._serialized_start=818
  _globals['_MSGDEPOSITCLAIM']._serialized_end=1049
  _globals['_MSGDEPOSITCLAIMRESPONSE']._serialized_start=1051
  _globals['_MSGDEPOSITCLAIMRESPONSE']._serialized_end=1076
  _globals['_MSGWITHDRAWCLAIM']._serialized_start=1079
  _globals['_MSGWITHDRAWCLAIM']._serialized_end=1207
  _globals['_MSGWITHDRAWCLAIMRESPONSE']._serialized_start=1209
  _globals['_MSGWITHDRAWCLAIMRESPONSE']._serialized_end=1235
  _globals['_MSGCANCELSENDTOETH']._serialized_start=1237
  _globals['_MSGCANCELSENDTOETH']._serialized_end=1297
  _globals['_MSGCANCELSENDTOETHRESPONSE']._serialized_start=1299
  _globals['_MSGCANCELSENDTOETHRESPONSE']._serialized_end=1327
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_start=1330
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_end=1489
  _globals['_MSGVALSETUPDATEDCLAIMRESPONSE']._serialized_start=1491
  _globals['_MSGVALSETUPDATEDCLAIMRESPONSE']._serialized_end=1522
  _globals['_MSGSETORCHESTRATORADDRESS']._serialized_start=1524
  _globals['_MSGSETORCHESTRATORADDRESS']._serialized_end=1613
  _globals['_MSGSETORCHESTRATORADDRESSRESPONSE']._serialized_start=1615
  _globals['_MSGSETORCHESTRATORADDRESSRESPONSE']._serialized_end=1650
  _globals['_MSGFXORIGINATEDTOKENCLAIM']._serialized_start=1653
  _globals['_MSGFXORIGINATEDTOKENCLAIM']._serialized_end=1817
  _globals['_MSGFXORIGINATEDTOKENCLAIMRESPONSE']._serialized_start=1819
  _globals['_MSGFXORIGINATEDTOKENCLAIMRESPONSE']._serialized_end=1854
  _globals['_MSG']._serialized_start=1857
  _globals['_MSG']._serialized_end=2589
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.marginx.oracle.v1 import tx_pb2 as marginx_dot_oracle_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BatchSubmitOracleAnswers = channel.unary_unary(
                '/marginx.oracle.v1.Msg/BatchSubmitOracleAnswers',
                request_serializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgBatchSubmitOracleAnswers.SerializeToString,
                response_deserializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgBatchSubmitOracleAnswersResponse.FromString,
                )
        self.UpdateAggregator = channel.unary_unary(
                '/marginx.oracle.v1.Msg/UpdateAggregator',
                request_serializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgUpdateAggregator.SerializeToString,
                response_deserializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgUpdateAggregatorResponse.FromString,
                )
        self.PresetOracle = channel.unary_unary(
                '/marginx.oracle.v1.Msg/PresetOracle',
                request_serializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgPresetOracle.SerializeToString,
                response_deserializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgPresetOracleResponse.FromString,
                )


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BatchSubmitOracleAnswers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAggregator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PresetOracle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BatchSubmitOracleAnswers': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchSubmitOracleAnswers,
                    request_deserializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgBatchSubmitOracleAnswers.FromString,
                    response_serializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgBatchSubmitOracleAnswersResponse.SerializeToString,
            ),
            'UpdateAggregator': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAggregator,
                    request_deserializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgUpdateAggregator.FromString,
                    response_serializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgUpdateAggregatorResponse.SerializeToString,
            ),
            'PresetOracle': grpc.unary_unary_rpc_method_handler(
                    servicer.PresetOracle,
                    request_deserializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgPresetOracle.FromString,
                    response_serializer=marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgPresetOracleResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'marginx.oracle.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BatchSubmitOracleAnswers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/marginx.oracle.v1.Msg/BatchSubmitOracleAnswers',
            marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgBatchSubmitOracleAnswers.SerializeToString,
            marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgBatchSubmitOracleAnswersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAggregator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/marginx.oracle.v1.Msg/UpdateAggregator',
            marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgUpdateAggregator.SerializeToString,
            marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgUpdateAggregatorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PresetOracle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/marginx.oracle.v1.Msg/PresetOracle',
            marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgPresetOracle.SerializeToString,
            marginx_dot_oracle_dot_v1_dot_tx__pb2.MsgPresetOracleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethermint/evm/v1/evm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65thermint/evm/v1/evm.proto\x12\x10\x65thermint.evm.v1\x1a\x14gogoproto/gogo.proto\"\xb8\x02\n\x06Params\x12\'\n\tevm_denom\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"evm_denom\"\x12/\n\renable_create\x18\x02 \x01(\x08\x42\x18\xf2\xde\x1f\x14yaml:\"enable_create\"\x12+\n\x0b\x65nable_call\x18\x03 \x01(\x08\x42\x16\xf2\xde\x1f\x12yaml:\"enable_call\"\x12\x36\n\nextra_eips\x18\x04 \x03(\x03\x42\"\xe2\xde\x1f\tExtraEIPs\xf2\xde\x1f\x11yaml:\"extra_eips\"\x12P\n\x0c\x63hain_config\x18\x05 \x01(\x0b\x32\x1d.ethermint.evm.v1.ChainConfigB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"chain_config\"\x12\x1d\n\x15\x61llow_unprotected_txs\x18\x06 \x01(\x08\"\xf7\x0e\n\x0b\x43hainConfig\x12]\n\x0fhomestead_block\x18\x01 \x01(\tBD\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"homestead_block\"\x12k\n\x0e\x64\x61o_fork_block\x18\x02 \x01(\tBS\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x0c\x44\x41OForkBlock\xf2\xde\x1f\x15yaml:\"dao_fork_block\"\x12G\n\x10\x64\x61o_fork_support\x18\x03 \x01(\x08\x42-\xe2\xde\x1f\x0e\x44\x41OForkSupport\xf2\xde\x1f\x17yaml:\"dao_fork_support\"\x12\x66\n\x0c\x65ip150_block\x18\x04 \x01(\tBP\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x0b\x45IP150Block\xf2\xde\x1f\x13yaml:\"eip150_block\"\x12=\n\x0b\x65ip150_hash\x18\x05 \x01(\tB(\xe2\xde\x1f\nEIP150Hash\xf2\xde\x1f\x16yaml:\"byzantium_block\"\x12\x66\n\x0c\x65ip155_block\x18\x06 \x01(\tBP\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x0b\x45IP155Block\xf2\xde\x1f\x13yaml:\"eip155_block\"\x12\x66\n\x0c\x65ip158_block\x18\x07 \x01(\tBP\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x0b\x45IP158Block\xf2\xde\x1f\x13yaml:\"eip158_block\"\x12]\n\x0f\x62yzantium_block\x18\x08 \x01(\tBD\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"byzantium_block\"\x12g\n\x14\x63onstantinople_block\x18\t \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1byaml:\"constantinople_block\"\x12_\n\x10petersburg_block\x18\n \x01(\tBE\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"petersburg_block\"\x12[\n\x0eistanbul_block\x18\x0b \x01(\tBC\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x15yaml:\"istanbul_block\"\x12\x63\n\x12muir_glacier_block\x18\x0c \x01(\tBG\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x19yaml:\"muir_glacier_block\"\x12W\n\x0c\x62\x65rlin_block\x18\r \x01(\tBA\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x13yaml:\"berlin_block\"\x12W\n\x0clondon_block\x18\x11 \x01(\tBA\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x13yaml:\"london_block\"\x12\x65\n\x13\x61rrow_glacier_block\x18\x12 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"arrow_glacier_block\"\x12\x63\n\x12gray_glacier_block\x18\x14 \x01(\tBG\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x19yaml:\"gray_glacier_block\"\x12g\n\x14merge_netsplit_block\x18\x15 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1byaml:\"merge_netsplit_block\"\x12[\n\x0eshanghai_block\x18\x16 \x01(\tBC\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x15yaml:\"shanghai_block\"\x12W\n\x0c\x63\x61ncun_block\x18\x17 \x01(\tBA\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x13yaml:\"cancun_block\"J\x04\x08\x0e\x10\x0fJ\x04\x08\x0f\x10\x10J\x04\x08\x10\x10\x11J\x04\x08\x13\x10\x14R\ryolo_v3_blockR\x0b\x65wasm_blockR\x0e\x63\x61talyst_blockR\x10merge_fork_block\"#\n\x05State\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"D\n\x0fTransactionLogs\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12#\n\x04logs\x18\x02 \x03(\x0b\x32\x15.ethermint.evm.v1.Log\"\xfa\x01\n\x03Log\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0e\n\x06topics\x18\x02 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12%\n\x0c\x62lock_number\x18\x04 \x01(\x04\x42\x0f\xea\xde\x1f\x0b\x62lockNumber\x12$\n\x07tx_hash\x18\x05 \x01(\tB\x13\xea\xde\x1f\x0ftransactionHash\x12&\n\x08tx_index\x18\x06 \x01(\x04\x42\x14\xea\xde\x1f\x10transactionIndex\x12!\n\nblock_hash\x18\x07 \x01(\tB\r\xea\xde\x1f\tblockHash\x12\x1b\n\x05index\x18\x08 \x01(\x04\x42\x0c\xea\xde\x1f\x08logIndex\x12\x0f\n\x07removed\x18\t \x01(\x08\"\xd3\x01\n\x08TxResult\x12\x35\n\x10\x63ontract_address\x18\x01 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"contract_address\"\x12\r\n\x05\x62loom\x18\x02 \x01(\x0c\x12J\n\x07tx_logs\x18\x03 \x01(\x0b\x32!.ethermint.evm.v1.TransactionLogsB\x16\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:\"tx_logs\"\x12\x0b\n\x03ret\x18\x04 \x01(\x0c\x12\x10\n\x08reverted\x18\x05 \x01(\x08\x12\x10\n\x08gas_used\x18\x06 \x01(\x04:\x04\x88\xa0\x1f\x00\"K\n\x0b\x41\x63\x63\x65ssTuple\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12%\n\x0cstorage_keys\x18\x02 \x03(\tB\x0f\xea\xde\x1f\x0bstorageKeys:\x04\x88\xa0\x1f\x00\"\x9e\x03\n\x0bTraceConfig\x12\x0e\n\x06tracer\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\t\x12\x0e\n\x06reexec\x18\x03 \x01(\x04\x12\'\n\rdisable_stack\x18\x05 \x01(\x08\x42\x10\xea\xde\x1f\x0c\x64isableStack\x12+\n\x0f\x64isable_storage\x18\x06 \x01(\x08\x42\x12\xea\xde\x1f\x0e\x64isableStorage\x12\r\n\x05\x64\x65\x62ug\x18\x08 \x01(\x08\x12\r\n\x05limit\x18\t \x01(\x05\x12\x30\n\toverrides\x18\n \x01(\x0b\x32\x1d.ethermint.evm.v1.ChainConfig\x12\'\n\renable_memory\x18\x0b \x01(\x08\x42\x10\xea\xde\x1f\x0c\x65nableMemory\x12\x30\n\x12\x65nable_return_data\x18\x0c \x01(\x08\x42\x14\xea\xde\x1f\x10\x65nableReturnData\x12,\n\x12tracer_json_config\x18\r \x01(\tB\x10\xea\xde\x1f\x0ctracerConfigJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08R\x0e\x64isable_memoryR\x13\x64isable_return_dataB(Z&github.com/evmos/ethermint/x/evm/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ethermint.evm.v1.evm_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/evmos/ethermint/x/evm/types'
  _PARAMS.fields_by_name['evm_denom']._options = None
  _PARAMS.fields_by_name['evm_denom']._serialized_options = b'\362\336\037\020yaml:\"evm_denom\"'
  _PARAMS.fields_by_name['enable_create']._options = None
  _PARAMS.fields_by_name['enable_create']._serialized_options = b'\362\336\037\024yaml:\"enable_create\"'
  _PARAMS.fields_by_name['enable_call']._options = None
  _PARAMS.fields_by_name['enable_call']._serialized_options = b'\362\336\037\022yaml:\"enable_call\"'
  _PARAMS.fields_by_name['extra_eips']._options = None
  _PARAMS.fields_by_name['extra_eips']._serialized_options = b'\342\336\037\tExtraEIPs\362\336\037\021yaml:\"extra_eips\"'
  _PARAMS.fields_by_name['chain_config']._options = None
  _PARAMS.fields_by_name['chain_config']._serialized_options = b'\310\336\037\000\362\336\037\023yaml:\"chain_config\"'
  _CHAINCONFIG.fields_by_name['homestead_block']._options = None
  _CHAINCONFIG.fields_by_name['homestead_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"homestead_block\"'
  _CHAINCONFIG.fields_by_name['dao_fork_block']._options = None
  _CHAINCONFIG.fields_by_name['dao_fork_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\014DAOForkBlock\362\336\037\025yaml:\"dao_fork_block\"'
  _CHAINCONFIG.fields_by_name['dao_fork_support']._options = None
  _CHAINCONFIG.fields_by_name['dao_fork_support']._serialized_options = b'\342\336\037\016DAOForkSupport\362\336\037\027yaml:\"dao_fork_support\"'
  _CHAINCONFIG.fields_by_name['eip150_block']._options = None
  _CHAINCONFIG.fields_by_name['eip150_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\013EIP150Block\362\336\037\023yaml:\"eip150_block\"'
  _CHAINCONFIG.fields_by_name['eip150_hash']._options = None
  _CHAINCONFIG.fields_by_name['eip150_hash']._serialized_options = b'\342\336\037\nEIP150Hash\362\336\037\026yaml:\"byzantium_block\"'
  _CHAINCONFIG.fields_by_name['eip155_block']._options = None
  _CHAINCONFIG.fields_by_name['eip155_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\013EIP155Block\362\336\037\023yaml:\"eip155_block\"'
  _CHAINCONFIG.fields_by_name['eip158_block']._options = None
  _CHAINCONFIG.fields_by_name['eip158_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\013EIP158Block\362\336\037\023yaml:\"eip158_block\"'
  _CHAINCONFIG.fields_by_name['byzantium_block']._options = None
  _CHAINCONFIG.fields_by_name['byzantium_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"byzantium_block\"'
  _CHAINCONFIG.fields_by_name['constantinople_block']._options = None
  _CHAINCONFIG.fields_by_name['constantinople_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\033yaml:\"constantinople_block\"'
  _CHAINCONFIG.fields_by_name['petersburg_block']._options = None
  _CHAINCONFIG.fields_by_name['petersburg_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"petersburg_block\"'
  _CHAINCONFIG.fields_by_name['istanbul_block']._options = None
  _CHAINCONFIG.fields_by_name['istanbul_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\025yaml:\"istanbul_block\"'
  _CHAINCONFIG.fields_by_name['muir_glacier_block']._options = None
  _CHAINCONFIG.fields_by_name['muir_glacier_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\031yaml:\"muir_glacier_block\"'
  _CHAINCONFIG.fields_by_name['berlin_block']._options = None
  _CHAINCONFIG.fields_by_name['berlin_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\023yaml:\"berlin_block\"'
  _CHAINCONFIG.fields_by_name['london_block']._options = None
  _CHAINCONFIG.fields_by_name['london_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\023yaml:\"london_block\"'
  _CHAINCONFIG.fields_by_name['arrow_glacier_block']._options = None
  _CHAINCONFIG.fields_by_name['arrow_glacier_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"arrow_glacier_block\"'
  _CHAINCONFIG.fields_by_name['gray_glacier_block']._options = None
  _CHAINCONFIG.fields_by_name['gray_glacier_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\031yaml:\"gray_glacier_block\"'
  _CHAINCONFIG.fields_by_name['merge_netsplit_block']._options = None
  _CHAINCONFIG.fields_by_name['merge_netsplit_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\033yaml:\"merge_netsplit_block\"'
  _CHAINCONFIG.fields_by_name['shanghai_block']._options = None
  _CHAINCONFIG.fields_by_name['shanghai_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\025yaml:\"shanghai_block\"'
  _CHAINCONFIG.fields_by_name['cancun_block']._options = None
  _CHAINCONFIG.fields_by_name['cancun_block']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\023yaml:\"cancun_block\"'
  _LOG.fields_by_name['block_number']._options = None
  _LOG.fields_by_name['block_number']._serialized_options = b'\352\336\037\013blockNumber'
  _LOG.fields_by_name['tx_hash']._options = None
  _LOG.fields_by_name['tx_hash']._serialized_options = b'\352\336\037\017transactionHash'
  _LOG.fields_by_name['tx_index']._options = None
  _LOG.fields_by_name['tx_index']._serialized_options = b'\352\336\037\020transactionIndex'
  _LOG.fields_by_name['block_hash']._options = None
  _LOG.fields_by_name['block_hash']._serialized_options = b'\352\336\037\tblockHash'
  _LOG.fields_by_name['index']._options = None
  _LOG.fields_by_name['index']._serialized_options = b'\352\336\037\010logIndex'
  _TXRESULT.fields_by_name['contract_address']._options = None
  _TXRESULT.fields_by_name['contract_address']._serialized_options = b'\362\336\037\027yaml:\"contract_address\"'
  _TXRESULT.fields_by_name['tx_logs']._options = None
  _TXRESULT.fields_by_name['tx_logs']._serialized_options = b'\310\336\037\000\362\336\037\016yaml:\"tx_logs\"'
  _TXRESULT._options = None
  _TXRESULT._serialized_options = b'\210\240\037\000'
  _ACCESSTUPLE.fields_by_name['storage_keys']._options = None
  _ACCESSTUPLE.fields_by_name['storage_keys']._serialized_options = b'\352\336\037\013storageKeys'
  _ACCESSTUPLE._options = None
  _ACCESSTUPLE._serialized_options = b'\210\240\037\000'
  _TRACECONFIG.fields_by_name['disable_stack']._options = None
  _TRACECONFIG.fields_by_name['disable_stack']._serialized_options = b'\352\336\037\014disableStack'
  _TRACECONFIG.fields_by_name['disable_storage']._options = None
  _TRACECONFIG.fields_by_name['disable_storage']._serialized_options = b'\352\336\037\016disableStorage'
  _TRACECONFIG.fields_by_name['enable_memory']._options = None
  _TRACECONFIG.fields_by_name['enable_memory']._serialized_options = b'\352\336\037\014enableMemory'
  _TRACECONFIG.fields_by_name['enable_return_data']._options = None
  _TRACECONFIG.fields_by_name['enable_return_data']._serialized_options = b'\352\336\037\020enableReturnData'
  _TRACECONFIG.fields_by_name['tracer_json_config']._options = None
  _TRACECONFIG.fields_by_name['tracer_json_config']._serialized_options = b'\352\336\037\014tracerConfig'
  _globals['_PARAMS']._serialized_start=71
  _globals['_PARAMS']._serialized_end=383
  _globals['_CHAINCONFIG']._serialized_start=386
  _globals['_CHAINCONFIG']._serialized_end=2297
  _globals['_STATE']._serialized_start=2299
  _globals['_STATE']._serialized_end=2334
  _globals['_TRANSACTIONLOGS']._serialized_start=2336
  _globals['_TRANSACTIONLOGS']._serialized_end=2404
  _globals['_LOG']._serialized_start=2407
  _globals['_LOG']._serialized_end=2657
  _globals['_TXRESULT']._serialized_start=2660
  _globals['_TXRESULT']._serialized_end=2871
  _globals['_ACCESSTUPLE']._serialized_start=2873
  _globals['_ACCESSTUPLE']._serialized_end=2948
  _globals['_TRACECONFIG']._serialized_start=2951
  _globals['_TRACECONFIG']._serialized_end=3365
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/crosschain/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.fx.crosschain.v1 import tx_pb2 as fx_dot_crosschain_dot_v1_dot_tx__pb2
from fxsdk.x.fx.crosschain.v1 import types_pb2 as fx_dot_crosschain_dot_v1_dot_types__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x66x/crosschain/v1/genesis.proto\x12\x18\x66x.gravity.crosschain.v1\x1a\x19\x66x/crosschain/v1/tx.proto\x1a\x1c\x66x/crosschain/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\xd3\x07\n\x0cGenesisState\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .fx.gravity.crosschain.v1.ParamsB\x04\xc8\xde\x1f\x00\x12!\n\x19last_observed_event_nonce\x18\x02 \x01(\x04\x12[\n\x1alast_observed_block_height\x18\x03 \x01(\x0b\x32\x31.fx.gravity.crosschain.v1.LastObservedBlockHeightB\x04\xc8\xde\x1f\x00\x12\x37\n\x07oracles\x18\x04 \x03(\x0b\x32 .fx.gravity.crosschain.v1.OracleB\x04\xc8\xde\x1f\x00\x12>\n\x0boracle_sets\x18\x05 \x03(\x0b\x32#.fx.gravity.crosschain.v1.OracleSetB\x04\xc8\xde\x1f\x00\x12\x42\n\rbridge_tokens\x18\x06 \x03(\x0b\x32%.fx.gravity.crosschain.v1.BridgeTokenB\x04\xc8\xde\x1f\x00\x12O\n\x13unbatched_transfers\x18\x07 \x03(\x0b\x32,.fx.gravity.crosschain.v1.OutgoingTransferTxB\x04\xc8\xde\x1f\x00\x12@\n\x07\x62\x61tches\x18\x08 \x03(\x0b\x32).fx.gravity.crosschain.v1.OutgoingTxBatchB\x04\xc8\xde\x1f\x00\x12P\n\x13oracle_set_confirms\x18\t \x03(\x0b\x32-.fx.gravity.crosschain.v1.MsgOracleSetConfirmB\x04\xc8\xde\x1f\x00\x12G\n\x0e\x62\x61tch_confirms\x18\n \x03(\x0b\x32).fx.gravity.crosschain.v1.MsgConfirmBatchB\x04\xc8\xde\x1f\x00\x12\x41\n\x0c\x61ttestations\x18\x0b \x03(\x0b\x32%.fx.gravity.crosschain.v1.AttestationB\x04\xc8\xde\x1f\x00\x12G\n\x0fproposal_oracle\x18\x0c \x01(\x0b\x32(.fx.gravity.crosschain.v1.ProposalOracleB\x04\xc8\xde\x1f\x00\x12K\n\x18last_observed_oracle_set\x18\r \x01(\x0b\x32#.fx.gravity.crosschain.v1.OracleSetB\x04\xc8\xde\x1f\x00\x12 \n\x18last_slashed_batch_block\x18\x0e \x01(\x04\x12%\n\x1dlast_slashed_oracle_set_nonce\x18\x0f \x01(\x04\x42\x31Z/github.com/functionx/fx-core/x/crosschain/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.crosschain.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/functionx/fx-core/x/crosschain/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['last_observed_block_height']._options = None
  _GENESISSTATE.fields_by_name['last_observed_block_height']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['oracles']._options = None
  _GENESISSTATE.fields_by_name['oracles']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['oracle_sets']._options = None
  _GENESISSTATE.fields_by_name['oracle_sets']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['bridge_tokens']._options = None
  _GENESISSTATE.fields_by_name['bridge_tokens']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['unbatched_transfers']._options = None
  _GENESISSTATE.fields_by_name['unbatched_transfers']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['batches']._options = None
  _GENESISSTATE.fields_by_name['batches']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['oracle_set_confirms']._options = None
  _GENESISSTATE.fields_by_name['oracle_set_confirms']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['batch_confirms']._options = None
  _GENESISSTATE.fields_by_name['batch_confirms']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['attestations']._options = None
  _GENESISSTATE.fields_by_name['attestations']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['proposal_oracle']._options = None
  _GENESISSTATE.fields_by_name['proposal_oracle']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['last_observed_oracle_set']._options = None
  _GENESISSTATE.fields_by_name['last_observed_oracle_set']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=140
  _globals['_GENESISSTATE']._serialized_end=1119
# @@protoc_insertion_point(module_scope)
